@@ -1,4 +1,4 @@
-from collections.abc import Iterable
+from collections.abc import Iterable as Iterable_
 from typing import Optional, Union, Iterable
 from datetime import datetime
 
@@ -6,9 +6,9 @@ import astropy.units as u
 import numpy as np
 
 from zodipy import models
-from zodipy import _coordinates as coords
-from zodipy import _integration as integ
 from zodipy import simulation 
+from zodipy import _coordinates
+from zodipy import _integration
 
 class Zodi:
     """Interface for simulating the Zodiacal emission.
@@ -22,8 +22,8 @@ class Zodi:
         self, 
         observer : Optional[str] = 'L2',
         observation_times : Optional[Union[Iterable[datetime], datetime]] = None,
-        model : Optional[models.InterplanetaryDustModel] = models.PLANCK_2018,
-        integration_config : Optional[integ.IntegrationConfig] = integ.DEFAULT,
+        model : Optional[str] = 'planck 2018',
+        integration_config : Optional[str] = 'default'
     ) -> None:
         """Initializing the zodi interface.
 
@@ -39,28 +39,52 @@ class Zodi:
             The times of observation. Must be an iterable containing 
             `datetime` objects. Defaults to a single observeration at the 
             current time.
-        model : `zodipy.models.Model`, optional
-            The Interplanteary dust model used in the simulation. Defaults 
-            to the model used in the Planck 2018 analysis.
-        integ : `zodipy.integration.IntegrationConfig`, optional
-            Integration config object determining the integration details
-            used in the simulation.
+        model : str, optional
+            String representing the Interplanteary dust model used in the 
+            simulation. Available options are 'planck 2013', 'planck 2015',
+            and 'planck 2018'. Defaults to 'planck 2018'.
+        integration_config : str, optional
+            String representing the integration config which determins the 
+            integration details used in the simulation. Available options
+            'default', and 'high'. Defaults to 'default'.
         """
 
         if observation_times is None:
-            observation_times = [datetime.now().date]
-        elif not isinstance(observation_times, Iterable): 
+            observation_times = [datetime.now().date()]
+        elif not isinstance(observation_times, Iterable_): 
             observation_times = [observation_times]
 
         observer_locations = [
-            coords.get_target_coordinates(observer, time) 
+            _coordinates.get_target_coordinates(observer, time) 
             for time in observation_times
         ]
         earth_locations = [
-            coords.get_target_coordinates('earth', time) 
+            _coordinates.get_target_coordinates('earth', time) 
             for time in observation_times
         ]
 
+        if 'planck' in model.lower():
+            if '2013' in model:
+                model = models.PLANCK_2013
+            elif '2015' in model:
+                model = models.PLANCK_2015
+            elif '2018' in model:
+                model = models.PLANCK_2018
+            else:
+                raise ValueError(
+                    "Available models are: 'planck 2013', 'planck 2015', and "
+                    "'planck 2018'"
+                )
+        
+        if integration_config == 'default':
+            integration_config = _integration.DEFAULT
+        elif integration_config == 'high':
+            integration_config = _integration.HIGH
+        else:
+            raise ValueError(
+                "Available configs are: 'default' and 'high'"
+            )
+
         self.simulation_strategy = simulation.InstantaneousStrategy(
             model, integration_config, observer_locations, earth_locations
         )
@@ -102,7 +126,6 @@ class Zodi:
 
         emission = self.simulation_strategy.simulate(nside, freq)
 
-        if coord != 'E':
-            emission = coords.change_coordinate_system(emission, coord)
+        emission = _coordinates.change_coordinate_system(emission, coord)
 
         return emission if return_comps else emission.sum(axis=0)
\ No newline at end of file
